/*

  Demonstrates simple RX and TX operation.
  Any of the Basic_RX examples can be used as a receiver.
  Please read through 'NRFLite.h' for a description of all the methods available in the library.

  Radio    Arduino
  CE    -> 9
  CSN   -> 10 (Hardware SPI SS)
  MOSI  -> 11 (Hardware SPI MOSI)
  MISO  -> 12 (Hardware SPI MISO)
  SCK   -> 13 (Hardware SPI SCK)
  IRQ   -> No connection
  VCC   -> No more than 3.6 volts
  GND   -> GND

*/

#include "SPI.h"
#include "NRFLite.h"

const static uint8_t RADIO_ID = 1;             // Our radio's id.
const static uint8_t DESTINATION_RADIO_ID = 0; // Id of the radio we will transmit to.
const static uint8_t PIN_RADIO_CE = 7;
const static uint8_t PIN_RADIO_CSN = 10;

struct RadioPacket // Any packet up to 32 bytes can be sent.
{
  float valuev;
};

NRFLite _radio;
RadioPacket _radioData;

int analogInput = A3;
float vout = 0.0;
float vin = 0.0;
float R1 = 198600.0; // resistance of Positive resistor adjust as nessesary
float R2 = 10000.0; // resistance of R2 (10K) again adjust if nessasary
float value = 0;

void setup()
{
  pinMode(analogInput, INPUT);
  Serial.begin(115200);

  // By default, 'init' configures the radio to use a 2MBPS bitrate on channel 100 (channels 0-125 are valid).
  // Both the RX and TX radios must have the same bitrate and channel to communicate with each other.
  // You can run the 'ChannelScanner' example to help select the best channel for your environment.
  // You can assign a different bitrate and channel as shown below.
  //   _radio.init(RADIO_ID, PIN_RADIO_CE, PIN_RADIO_CSN, NRFLite::BITRATE2MBPS, 100) // THE DEFAULT
  //   _radio.init(RADIO_ID, PIN_RADIO_CE, PIN_RADIO_CSN, NRFLite::BITRATE1MBPS, 75)
  //   _radio.init(RADIO_ID, PIN_RADIO_CE, PIN_RADIO_CSN, NRFLite::BITRATE250KBPS, 0)

  if (!_radio.init(RADIO_ID, PIN_RADIO_CE, PIN_RADIO_CSN, NRFLite::BITRATE250KBPS, 125))
  {
    Serial.println("Cannot communicate with radio");
    while (1); // Wait here forever.
  }

}

void loop()
{
  value = analogRead(analogInput);
  Serial.println(vin);
  vout = (value * 5.0) / 1024.0; // see text
  vin = vout / (R2 / (R1 + R2));
  if (vin < 0.09) {
    vin = 0.0; //statement to quash undesired reading !
  }

  _radioData.valuev = vin;

  Serial.print(_radioData.valuev);

  if (_radio.send(DESTINATION_RADIO_ID, &_radioData, sizeof(_radioData))) // Note how '&' must be placed in front of the variable name.
  {
    Serial.println("...Success");
  }
  else
  {
    Serial.println("...Failed");
  }

  //delay(50); // use if needed, i didnt
}
